# Vizro

Vizro is a toolkit for creating modular data visualization applications.

<div class="grid cards" markdown>

-   :fontawesome-solid-forward-fast:{ .lg .middle } __New to Vizro?__

    ---

    Quick start tutorial to explore key features.

    [:octicons-arrow-right-24: Get started](pages/tutorials/first-dashboard/)

-   :fontawesome-solid-keyboard:{ .lg .middle } __Get hands-on__

    ---

    Step-by-step instructions on key Vizro features.

    [:octicons-arrow-right-24: How-to guides](pages/user-guides/dashboard/)

-   :fontawesome-solid-microscope:{ .lg .middle } __Get the detail__

    ---

    API reference for Vizro and our pydantic models.

    [:octicons-arrow-right-24: API Reference](pages/API-reference/vizro/)

-   :material-scale-balance:{ .lg .middle } __Vizro explained__

    ---

    Background information and answers to your "Why..?" questions.

    [:octicons-arrow-right-24: Explanation](pages/explanation/why-vizro/)

-   :fontawesome-solid-hands-holding-circle:{ .lg .middle } __Contribution guidelines__

    ---

    Find out more about contributing to Vizro.

    [:octicons-arrow-right-24: Contribute](pages/development/contributing/)

-   :fontawesome-solid-chart-column:{ .lg .middle } __Vizro-AI__

    ---

    Use natural language queries to build Plotly charts.

    [:octicons-arrow-right-24: Vizro-AI](https://vizro.readthedocs.io/projects/vizro-ai/en/latest/)


</div>
